@@ -27,18 +27,18 @@ namespace PrimeSieve {
     //             b <- sapply(seq(40000, 120000, 10), function(x) x/log(x))
     //             myDiff <- a - b;  max(myDiff / b) ## [1] 0.1153694
     
-    constexpr std::array<double, 15> PERCINC = {0.2500, 0.1160, 0.1030, 0.0850, 0.0712,
-                                                0.0614, 0.0538, 0.0495, 0.0480, 0.0431, 
-                                                0.0392, 0.0360, 0.0332, 0.0309, 0.0292};
+    constexpr std::array<double, 15> PERCINC = {{0.2500, 0.1160, 0.1030, 0.0850, 0.0712,
+                                                 0.0614, 0.0538, 0.0495, 0.0480, 0.0431, 
+                                                 0.0392, 0.0360, 0.0332, 0.0309, 0.0292}};
     
-    constexpr std::array<double, 15> CUTPOINTS = {40000.0,            120000.0,
-                                                  1000000.0,          10000000.0,
-                                                  100000000.0,        1000000000.0,
-                                                  5000000000.0,       10000000000.0,
-                                                  100000000000.0,     1000000000000.0,
-                                                  10000000000000.0,   100000000000000.0,
-                                                  1000000000000000.0, 5000000000000000.0,
-                                                  10000000000000000.0};
+    constexpr std::array<double, 15> CUTPOINTS = {{40000.0,            120000.0,
+                                                   1000000.0,          10000000.0,
+                                                   100000000.0,        1000000000.0,
+                                                   5000000000.0,       10000000000.0,
+                                                   100000000000.0,     1000000000000.0,
+                                                   10000000000000.0,   100000000000000.0,
+                                                   1000000000000000.0, 5000000000000000.0,
+                                                   10000000000000000.0}};
     
     // The following function is based off of the prime number theorem
     inline std::size_t EstimatePiPrime(double minNum, double maxNum) {
@@ -620,10 +620,10 @@ namespace PrimeSieve {
     }
     
     template <typename typePrime>
-    void PrimeSlave(std::int_fast64_t minNum, std::int_fast64_t maxNum, const std::vector<std::int_fast64_t> &svPriMain,
-                    const std::vector<std::int_fast64_t> &svPriOne, const std::vector<std::int_fast64_t> &svPriTwo, 
-                    std::vector<typePrime> &primes, std::int_fast64_t smallCut, std::int_fast64_t medCut, 
-                    std::size_t nBigSegs, const std::vector<char> &check30030) {
+    void PrimeWorker(std::int_fast64_t minNum, std::int_fast64_t maxNum, const std::vector<std::int_fast64_t> &svPriMain,
+                     const std::vector<std::int_fast64_t> &svPriOne, const std::vector<std::int_fast64_t> &svPriTwo, 
+                     std::vector<typePrime> &primes, std::int_fast64_t smallCut, std::int_fast64_t medCut, 
+                     std::size_t nBigSegs, const std::vector<char> &check30030) {
         
         if (maxNum > medCut) {
             // PrimeSieveBig is not meant for small values, so we
@@ -748,16 +748,16 @@ namespace PrimeSieve {
             upperBnd = segSize * std::floor(minNum / segSize) + chunkSize;
             
             for (; ind < (nThreads - 1); lowerBnd = upperBnd, upperBnd += chunkSize, ++ind) {
-                pool.push(std::cref(PrimeSlave<typePrime>), lowerBnd, upperBnd, std::ref(svPriMain), std::ref(svPriOne),
+                pool.push(std::cref(PrimeWorker<typePrime>), lowerBnd, upperBnd, std::ref(svPriMain), std::ref(svPriOne),
                           std::ref(svPriTwo), std::ref(primeList[ind]), smallCut, medCut, nBigSegs, std::ref(check30030));
             }
             
-            pool.push(std::cref(PrimeSlave<typePrime>), lowerBnd, maxNum, std::ref(svPriMain), std::ref(svPriOne),
+            pool.push(std::cref(PrimeWorker<typePrime>), lowerBnd, maxNum, std::ref(svPriMain), std::ref(svPriOne),
                       std::ref(svPriTwo), std::ref(primeList[ind]), smallCut, medCut, nBigSegs, std::ref(check30030));
             
             pool.join();
         } else {
-            PrimeSlave(minNum, maxNum, svPriMain, svPriOne, svPriTwo, primes, smallCut, medCut, nBigSegs, check30030);
+            PrimeWorker(minNum, maxNum, svPriMain, svPriOne, svPriTwo, primes, smallCut, medCut, nBigSegs, check30030);
         }
     }
 }
